# Roadmap

- [x] GitHub setup
- [x] Auto-release
- [x] Breaking change works
- [x] `chmod +x`, but on Windows
- [ ] bug_report's `version.options`: change to
  1. Current (vX.Y.Z)
  2. Previous (vX.Y-1.Z)
  3. Older, than vX.Y-1.Z
- [ ] New GitHub YAMLs in template
- [ ] GitHub bootstrap action
- [ ] Tests
- [ ] `proj-flow init <lang> --update`
